@@ -1,21 +1,7 @@
 /*
- * Copyright 2014 Christian Mollekopf <mollekopf@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Christian Mollekopf <mollekopf@kolabsys.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  *
  */
 
@@ -55,7 +41,8 @@ static void removeDir(const QString &dirName)
 {
     QDir dir(dirName);
     if (dir.exists(dirName)) {
-        for (const QFileInfo &info : dir.entryInfoList(QDir::NoDotAndDotDot | QDir::System | QDir::Hidden  | QDir::AllDirs | QDir::Files, QDir::DirsFirst)) {
+        const auto dirs = dir.entryInfoList(QDir::NoDotAndDotDot | QDir::System | QDir::Hidden  | QDir::AllDirs | QDir::Files, QDir::DirsFirst);
+        for (const QFileInfo &info : dirs) {
             if (info.isDir()) {
                 removeDir(info.absoluteFilePath());
             } else {
@@ -201,7 +188,8 @@ void Index::change(const Akonadi::Collection &col)
 void Index::remove(const Akonadi::Collection &col)
 {
     //Remove items
-    for (AbstractIndexer *indexer : indexersForMimetypes(col.contentMimeTypes())) {
+    const auto indexers = indexersForMimetypes(col.contentMimeTypes());
+    for (AbstractIndexer *indexer : indexers) {
         try {
             indexer->remove(col);
         } catch (const Xapian::Error &e) {
@@ -226,7 +214,8 @@ void Index::move(const Akonadi::Collection &collection, const Akonadi::Collectio
 void Index::addIndexer(AbstractIndexer *indexer)
 {
     m_listIndexer.append(indexer);
-    for (const QString &mimeType : indexer->mimeTypes()) {
+    const QStringList indexerMimetypes = indexer->mimeTypes();
+    for (const QString &mimeType : indexerMimetypes) {
         m_indexer.insert(mimeType, indexer);
     }
 }
