@@ -1,22 +1,8 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * Copyright (C) 2013  Vishesh Handa <me@vhanda.in>
+ * SPDX-FileCopyrightText: 2013 Vishesh Handa <me@vhanda.in>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
  */
 
@@ -297,7 +283,7 @@ QByteArray Query::toJSON() const
         map[QStringLiteral("sortingProperty")] = d->m_sortingProperty;
     }
 
-    if (d->m_customOptions.size()) {
+    if (!d->m_customOptions.isEmpty()) {
         map[QStringLiteral("customOptions")] = d->m_customOptions;
     }
 
@@ -316,7 +302,7 @@ Query Query::fromJSON(const QByteArray &arr)
     Query query;
     query.d->m_types = map[QStringLiteral("type")].toStringList();
 
-    if (map.contains(QLatin1String("limit"))) {
+    if (map.contains(QStringLiteral("limit"))) {
         query.d->m_limit = map[QStringLiteral("limit")].toUInt();
     } else {
         query.d->m_limit = defaultLimit;
@@ -326,26 +312,26 @@ Query Query::fromJSON(const QByteArray &arr)
     query.d->m_searchString = map[QStringLiteral("searchString")].toString();
     query.d->m_term = Term::fromVariantMap(map[QStringLiteral("term")].toMap());
 
-    if (map.contains(QLatin1String("yearFilter"))) {
+    if (map.contains(QStringLiteral("yearFilter"))) {
         query.d->m_yearFilter = map[QStringLiteral("yearFilter")].toInt();
     }
-    if (map.contains(QLatin1String("monthFilter"))) {
+    if (map.contains(QStringLiteral("monthFilter"))) {
         query.d->m_monthFilter = map[QStringLiteral("monthFilter")].toInt();
     }
-    if (map.contains(QLatin1String("dayFilter"))) {
+    if (map.contains(QStringLiteral("dayFilter"))) {
         query.d->m_dayFilter = map[QStringLiteral("dayFilter")].toInt();
     }
 
-    if (map.contains(QLatin1String("sortingOption"))) {
+    if (map.contains(QStringLiteral("sortingOption"))) {
         int option = map.value(QStringLiteral("sortingOption")).toInt();
         query.d->m_sortingOption = static_cast<SortingOption>(option);
     }
 
-    if (map.contains(QLatin1String("sortingProperty"))) {
+    if (map.contains(QStringLiteral("sortingProperty"))) {
         query.d->m_sortingProperty = map.value(QStringLiteral("sortingProperty")).toString();
     }
 
-    if (map.contains(QLatin1String("customOptions"))) {
+    if (map.contains(QStringLiteral("customOptions"))) {
         QVariant var = map[QStringLiteral("customOptions")];
         if (var.type() == QVariant::Map) {
             query.d->m_customOptions = map[QStringLiteral("customOptions")].toMap();
