@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef AKONADISEARCHDEBUGDIALOG_H
@@ -24,10 +12,8 @@
 #include "akonadisearchdebugsearchpathcombobox.h"
 #include <AkonadiCore/Item>
 
-namespace Akonadi
-{
-namespace Search
-{
+namespace Akonadi {
+namespace Search {
 class AkonadiSearchDebugDialogPrivate;
 /**
  * @brief The AkonadiSearchDebugDialog class
@@ -55,4 +41,3 @@ private:
 }
 }
 #endif // AKONADISEARCHDEBUGDIALOG_H
-
